import { Connection, EntityManager, IDatabaseDriver, MikroORM } from '@mikro-orm/core';
import { FactoryContainer } from '../factory-container';
/**
 * Get a sample database connection for a fake postgres database
 * @returns an instantiated database connection string
 */
export declare const getConnectionOrm: () => Promise<MikroORM<IDatabaseDriver<Connection>>>;
/**
 * Get all of the database entities associated with a database connection
 *
 * @param connection: A database connection string
 * @returns an array of objects for name and table name
 */
export declare const getDBEntities: (em: EntityManager) => {
    name: string;
    tableName: string;
}[];
/**
 * Clear all database tables via connection
 *
 * @param connection: Database connection clear
 * @returns a promise that the Database has been cleared
 */
export declare const clearDB: (em: EntityManager) => Promise<void>;
export declare const loadSchema: (orm: MikroORM<IDatabaseDriver<Connection>>) => Promise<void>;
/**
 * Get a stub factory container for testing
 * @returns an instantiated container
 */
export declare const getContainer: (em: EntityManager) => Promise<FactoryContainer>;
