/**
 * The FactoryContainer maps entity class name strings
 * to their respective factory classes.
 *
 * @example
 * class Book {...}
 *
 * @FactoryFor(Book)
 * class BookFactory {...}
 *
 * Then within the container, the class name passed
 * into factory for is retrieve and mapped.
 *
 * @param entity: The entity class to map to in container
 * @param namespaceKey: A namespacing string to allow for multiple factories for the same entity
 * @returns TS class decorator function
 */
export declare const FactoryFor: (entity: any, namespaceKey?: string) => (target: any) => void;
export declare function getFactoryFor(target: any): {
    entityName: string;
    namespaceKey: string;
};
