"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFactoryFor = exports.FactoryFor = void 0;
/** Private access symbol */
var factoryForKey = Symbol('mikro-orm-entity-factory:FactoryFor');
/**
 * The FactoryContainer maps entity class name strings
 * to their respective factory classes.
 *
 * @example
 * class Book {...}
 *
 * @FactoryFor(Book)
 * class BookFactory {...}
 *
 * Then within the container, the class name passed
 * into factory for is retrieve and mapped.
 *
 * @param entity: The entity class to map to in container
 * @param namespaceKey: A namespacing string to allow for multiple factories for the same entity
 * @returns TS class decorator function
 */
var FactoryFor = function (entity, namespaceKey) {
    if (namespaceKey === void 0) { namespaceKey = ''; }
    return function (target) {
        var entityName = entity.name;
        Reflect.defineMetadata(factoryForKey, { entityName: entityName, namespaceKey: namespaceKey }, target);
    };
};
exports.FactoryFor = FactoryFor;
function getFactoryFor(target) {
    return Reflect.getMetadata(factoryForKey, target);
}
exports.getFactoryFor = getFactoryFor;
